import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'assistant.dart';
import 'cupertino_picker_wrap.dart';
import 'flexible.dart';

double _defaultHeight = 345.0.w;
const String _defaultTitle = '请选择项目';

typedef ItemPickerCallback = void Function(int index, String item);

/// 单条 item 选择器
class TCRItemPicker extends StatefulWidget {
  final int initialIndex;
  final String title;
  final double? height;
  final List<String> items;
  final ItemPickerCallback? callback;

  TCRItemPicker({
    this.initialIndex = 0,
    this.title = _defaultTitle,
    this.height,
    this.items = const [],
    this.callback,
  }) : super() {
    assert(initialIndex < items.length, 'TCRItemPicker 参数错误');
  }

  @override
  _TCRItemPickerState createState() => _TCRItemPickerState();
}

class _TCRItemPickerState extends State<TCRItemPicker> {
  int _selectedValue = 0;

  @override
  void initState() {
    _selectedValue = widget.initialIndex;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    XFlexible.registerWidth(MediaQuery.of(context).size.width);
    return Container(
      decoration: BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(10.w),
          topRight: Radius.circular(10.w),
        ),
      ),
      child: SafeArea(
        child: Container(
          height: widget.height ?? _defaultHeight,
          child: Column(
            children: <Widget>[
              Header(
                callback: () {
                  Navigator.of(context).maybePop();
                },
                title: widget.title,
              ),
              Expanded(
                child: Container(
                  color: Colors.white,
                  padding: EdgeInsets.symmetric(horizontal: 30.0.w),
                  child: CupertinoPickerWrap(
                    onChange: (value) {
                      setState(() {
                        _selectedValue = value;
                      });
                    },
                    selectedIndex: _selectedValue,
                    items: widget.items,
                  ),
                ),
              ),
              Bottom(
                callback: () {
                  Navigator.of(context).maybePop();
                  widget.callback?.call(_selectedValue, widget.items[_selectedValue]);
                },
              ),
            ],
          ),
        ),
      ),
    );
  }
}
